API docs for “spamfighter.interfaces.IMessageFirewall”

# Class s.i.IMessageFirewall(Interface):

Part of spamfighter.interfaces View Source View In Hierarchy

Маркерный интерфейс файрвола.

Method | getRules | Получить текущие правила firewall'а.
Method | setRules | Установить новые правила анализа.
Method | syntaxCheck | Осуществить синтаксическую проверку текста правил.

def getRules(): (source)
Получить текущие правила firewall'а.

Returns | текстовое представление текущих правил. (type: `str` )

def setRules(rules): (source)
Установить новые правила анализа.

Parameters | rules | правила анализа (type: `str` )

def syntaxCheck(rules): (source)
Осуществить синтаксическую проверку текста правил.

Parameters | rules | правила анализа (type: `str` )